@@ -87,7 +87,7 @@ gboolean anjuta_launcher_execute_v (AnjutaLauncher *launcher,
 									gchar *const argv[],
 									AnjutaLauncherOutputCallback callback,
 									gpointer callback_data);
-gboolean anjuta_launcher_set_encoding (AnjutaLauncher *launcher,
+void anjuta_launcher_set_encoding (AnjutaLauncher *launcher,
 									   const gchar *charset);
 void anjuta_launcher_send_stdin (AnjutaLauncher *launcher,
 								 const gchar *input_str);
@@ -108,9 +108,6 @@ gboolean anjuta_launcher_set_terminal_echo (AnjutaLauncher *launcher,
 gboolean anjuta_launcher_set_terminate_on_exit (AnjutaLauncher *launcher,
 		gboolean terminate_on_exit);
 
-void anjuta_launcher_disable_password_check (AnjutaLauncher* launcher,
-                                                 gboolean disable);
-
 G_END_DECLS
 
 #endif				/* __ANJUTA_LAUNCHER_H__ */
