@@ -26,33 +26,33 @@ extern void libanjuta_iface_cclosure_marshal_VOID__BOOLEAN_INT (GClosure     *cl
 /* VOID:INT (./libanjuta-iface-marshallers.list:5) */
 #define libanjuta_iface_cclosure_marshal_VOID__INT	g_cclosure_marshal_VOID__INT
 
-/* VOID:INT,BOOLEAN,INT,INT,STRING (./libanjuta-iface-marshallers.list:6) */
-extern void libanjuta_iface_cclosure_marshal_VOID__INT_BOOLEAN_INT_INT_STRING (GClosure     *closure,
-                                                                               GValue       *return_value,
-                                                                               guint         n_param_values,
-                                                                               const GValue *param_values,
-                                                                               gpointer      invocation_hint,
-                                                                               gpointer      marshal_data);
+/* VOID:INT,INT,ULONG,STRING,UINT (./libanjuta-iface-marshallers.list:6) */
+extern void libanjuta_iface_cclosure_marshal_VOID__INT_INT_ULONG_STRING_UINT (GClosure     *closure,
+                                                                              GValue       *return_value,
+                                                                              guint         n_param_values,
+                                                                              const GValue *param_values,
+                                                                              gpointer      invocation_hint,
+                                                                              gpointer      marshal_data);
 
-/* VOID:INT,CHAR (./libanjuta-iface-marshallers.list:7) */
-extern void libanjuta_iface_cclosure_marshal_VOID__INT_CHAR (GClosure     *closure,
-                                                             GValue       *return_value,
-                                                             guint         n_param_values,
-                                                             const GValue *param_values,
-                                                             gpointer      invocation_hint,
-                                                             gpointer      marshal_data);
-
-/* VOID:INT,INT,UINT,STRING,UINT (./libanjuta-iface-marshallers.list:8) */
-extern void libanjuta_iface_cclosure_marshal_VOID__INT_INT_UINT_STRING_UINT (GClosure     *closure,
-                                                                             GValue       *return_value,
-                                                                             guint         n_param_values,
-                                                                             const GValue *param_values,
-                                                                             gpointer      invocation_hint,
-                                                                             gpointer      marshal_data);
-
-/* VOID:OBJECT (./libanjuta-iface-marshallers.list:9) */
+/* VOID:OBJECT (./libanjuta-iface-marshallers.list:7) */
 #define libanjuta_iface_cclosure_marshal_VOID__OBJECT	g_cclosure_marshal_VOID__OBJECT
 
+/* VOID:OBJECT,BOOLEAN,INT,INT,STRING (./libanjuta-iface-marshallers.list:8) */
+extern void libanjuta_iface_cclosure_marshal_VOID__OBJECT_BOOLEAN_INT_INT_STRING (GClosure     *closure,
+                                                                                  GValue       *return_value,
+                                                                                  guint         n_param_values,
+                                                                                  const GValue *param_values,
+                                                                                  gpointer      invocation_hint,
+                                                                                  gpointer      marshal_data);
+
+/* VOID:OBJECT,CHAR (./libanjuta-iface-marshallers.list:9) */
+extern void libanjuta_iface_cclosure_marshal_VOID__OBJECT_CHAR (GClosure     *closure,
+                                                                GValue       *return_value,
+                                                                guint         n_param_values,
+                                                                const GValue *param_values,
+                                                                gpointer      invocation_hint,
+                                                                gpointer      marshal_data);
+
 /* VOID:POINTER (./libanjuta-iface-marshallers.list:10) */
 #define libanjuta_iface_cclosure_marshal_VOID__POINTER	g_cclosure_marshal_VOID__POINTER
 
@@ -75,13 +75,13 @@ extern void libanjuta_iface_cclosure_marshal_VOID__UINT_INT (GClosure     *closu
                                                              gpointer      invocation_hint,
                                                              gpointer      marshal_data);
 
-/* VOID:UINT,STRING,UINT (./libanjuta-iface-marshallers.list:14) */
-extern void libanjuta_iface_cclosure_marshal_VOID__UINT_STRING_UINT (GClosure     *closure,
-                                                                     GValue       *return_value,
-                                                                     guint         n_param_values,
-                                                                     const GValue *param_values,
-                                                                     gpointer      invocation_hint,
-                                                                     gpointer      marshal_data);
+/* VOID:ULONG,STRING,UINT (./libanjuta-iface-marshallers.list:14) */
+extern void libanjuta_iface_cclosure_marshal_VOID__ULONG_STRING_UINT (GClosure     *closure,
+                                                                      GValue       *return_value,
+                                                                      guint         n_param_values,
+                                                                      const GValue *param_values,
+                                                                      gpointer      invocation_hint,
+                                                                      gpointer      marshal_data);
 
 /* VOID:VOID (./libanjuta-iface-marshallers.list:15) */
 #define libanjuta_iface_cclosure_marshal_VOID__VOID	g_cclosure_marshal_VOID__VOID
