@@ -118,13 +118,28 @@ on_assist_cancel(AssistWindow* assist_win, Sourceview* sv)
 	}
 }
 
-/* Called when a character is added */
-static void on_document_char_added(AnjutaView* view, IAnjutaIterable* pos,
-								   gchar ch,
-								   Sourceview* sv)
+static void on_insert_text (GtkTextBuffer* buffer, 
+							GtkTextIter* location,
+							char* text,
+							gint len,
+							Sourceview* sv)
 {
-	if (ch != '\0')
-		g_signal_emit_by_name(G_OBJECT(sv), "char_added", pos, ch);
+	/* We only want ascii characters */
+	if (len > 1)
+		return;
+	else
+	{
+		int offset = gtk_text_iter_get_offset (location);
+		SourceviewCell* cell = sourceview_cell_new (location, 
+													GTK_TEXT_VIEW(sv->priv->view));
+		ianjuta_iterable_previous (IANJUTA_ITERABLE (cell), NULL);
+		g_signal_handlers_block_by_func (buffer, on_insert_text, sv);
+		g_signal_emit_by_name(G_OBJECT(sv), "char_added", cell, text[0]);
+		g_signal_handlers_unblock_by_func (buffer, on_insert_text, sv);
+		/* Reset iterator */
+		gtk_text_buffer_get_iter_at_offset (buffer, location,
+											offset);
+	}
 }
 
 /* Called whenever the document is changed */
@@ -166,7 +181,7 @@ sourceview_remove_monitor(Sourceview* sv)
 {
 	gboolean monitor_enabled = anjuta_preferences_get_int (sv->priv->prefs, MONITOR_KEY);
 
-	if (monitor_enabled && sv->priv->monitor != NULL) 
+	if (monitor_enabled && sv->priv->monitor != NULL)
 	{
 		DEBUG_PRINT ("Monitor removed for %s", anjuta_document_get_uri(sv->priv->document));
 		gnome_vfs_monitor_cancel(sv->priv->monitor);
@@ -249,11 +264,14 @@ sourceview_add_monitor(Sourceview* sv)
 
 	if (monitor_enabled)
 	{
+		gchar* uri;
 		g_return_val_if_fail(sv->priv->monitor == NULL, FALSE);
-		DEBUG_PRINT ("Monitor added for %s", anjuta_document_get_uri(sv->priv->document)); 	
-		gnome_vfs_monitor_add(&sv->priv->monitor, anjuta_document_get_uri(sv->priv->document),
+		DEBUG_PRINT ("Monitor added for %s", anjuta_document_get_uri(sv->priv->document));
+		uri = anjuta_document_get_uri(sv->priv->document);
+		gnome_vfs_monitor_add(&sv->priv->monitor, uri,
 							  GNOME_VFS_MONITOR_FILE,
-						  on_sourceview_uri_changed, sv);
+							  on_sourceview_uri_changed, sv);
+		g_free (uri);
 	}
 	return FALSE; /* for g_idle_add */
 }
@@ -541,16 +559,17 @@ static void sourceview_create_highligth_indic(Sourceview* sv)
 {	
 	sv->priv->important_indic = 
 		gtk_text_buffer_create_tag (GTK_TEXT_BUFFER(sv->priv->document),
-		IMPORTANT_INDIC,
-		"background", "#FFFF00", NULL);  
+									IMPORTANT_INDIC,
+									"background", "#FFFF00", NULL);  
 	sv->priv->warning_indic = 
 		gtk_text_buffer_create_tag (GTK_TEXT_BUFFER(sv->priv->document),
-		WARNING_INDIC,
-		"foreground", "#00FF00", NULL); 
+									WARNING_INDIC,
+									"foreground", "#00FF00", NULL); 
 	sv->priv->critical_indic = 
 		gtk_text_buffer_create_tag (GTK_TEXT_BUFFER(sv->priv->document),
-		CRITICAL_INDIC,
-		"foreground", "#FF0000", "underline", PANGO_UNDERLINE_ERROR, NULL);
+									CRITICAL_INDIC,
+									"foreground", "#FF0000", "underline", 
+									PANGO_UNDERLINE_ERROR, NULL);
 }
 
 
@@ -578,11 +597,11 @@ sourceview_new(const gchar* uri, const gchar* filename, AnjutaPlugin* plugin)
 					 G_CALLBACK(on_document_saved), sv);
 	g_signal_connect(G_OBJECT(sv->priv->document), "saving", 
 					 G_CALLBACK(on_document_saving), sv);
+	g_signal_connect_after (G_OBJECT(sv->priv->document), "insert-text",
+					  G_CALLBACK(on_insert_text), sv);
 					 
 	/* Create View instance */
 	sv->priv->view = ANJUTA_VIEW(anjuta_view_new(sv));
-	g_signal_connect_after(G_OBJECT(sv->priv->view), "char_added",
-					G_CALLBACK(on_document_char_added), sv);
 #if HAVE_TOOLTIP_API
 	g_signal_connect (G_OBJECT(sv->priv->view), "query-tooltip",
 					  G_CALLBACK (on_sourceview_hover_over), sv);
@@ -731,6 +750,7 @@ ieditor_set_tab_size (IAnjutaEditor *editor, gint tabsize, GError **e)
 {
 	Sourceview* sv = ANJUTA_SOURCEVIEW(editor);
 	gtk_source_view_set_tab_width(GTK_SOURCE_VIEW(sv->priv->view), tabsize);
+	gtk_source_view_set_indent_width (GTK_SOURCE_VIEW (sv->priv->view), tabsize);
 }
 
 static gboolean
@@ -831,6 +851,19 @@ ieditor_get_position (IAnjutaEditor* editor, GError **e)
 	return IANJUTA_ITERABLE (cell);
 }
 
+static gint
+ieditor_get_offset (IAnjutaEditor* editor, GError **e)
+{
+	Sourceview* sv = ANJUTA_SOURCEVIEW(editor);
+	GtkTextBuffer* buffer = GTK_TEXT_BUFFER(sv->priv->document);
+	GtkTextIter iter;
+	
+	gtk_text_buffer_get_iter_at_mark(buffer, &iter, 
+									 gtk_text_buffer_get_insert(buffer));
+	
+	return gtk_text_iter_get_offset (&iter);
+}
+
 /* Return line of cursor */
 static gint ieditor_get_lineno(IAnjutaEditor *editor, GError **e)
 {
@@ -882,8 +915,14 @@ static void ieditor_insert(IAnjutaEditor *editor, IAnjutaIterable* icell,
 	GtkTextIter* iter = sourceview_cell_get_iter (cell);
 	Sourceview* sv = ANJUTA_SOURCEVIEW(editor);
 	
+	g_signal_handlers_block_by_func (sv->priv->document,
+										  on_insert_text,
+										  sv);
 	gtk_text_buffer_insert(GTK_TEXT_BUFFER(sv->priv->document),
 						   iter, text, length);
+	g_signal_handlers_unblock_by_func (sv->priv->document,
+									 on_insert_text,
+									 sv);
 }
 
 /* Append text to buffer */
@@ -1059,6 +1098,7 @@ ieditor_iface_init (IAnjutaEditorIface *iface)
 	iface->get_text = ieditor_get_text;
 	iface->get_text_all = ieditor_get_text_all;
 	iface->get_position = ieditor_get_position;
+	iface->get_offset = ieditor_get_offset;
 	iface->get_lineno = ieditor_get_lineno;
 	iface->get_length = ieditor_get_length;
 	iface->get_current_word = ieditor_get_current_word;
@@ -1137,10 +1177,9 @@ static void idocument_grab_focus (IAnjutaDocument *editor, GError **e)
 static const gchar* idocument_get_filename(IAnjutaDocument *editor, GError **e)
 {
 	Sourceview* sv = ANJUTA_SOURCEVIEW(editor);
-	if (sv->priv->filename != NULL)
-		return sv->priv->filename;
-	else
-		return anjuta_document_get_short_name_for_display(sv->priv->document);
+	if (sv->priv->filename == NULL)
+		sv->priv->filename = anjuta_document_get_short_name_for_display(sv->priv->document);
+	return sv->priv->filename;
 }
 
 static void 
@@ -1802,17 +1841,20 @@ static const GList*
 ilanguage_get_supported_languages (IAnjutaEditorLanguage *ilanguage,
 								   GError **err)
 {
-	GStrv langs;
-	GStrv lang;
-	GList* list = NULL;
-	g_object_get (gtk_source_language_manager_get_default(), "language-ids", &langs, NULL);
-	
-	for (lang = langs; *lang != NULL; lang++)
+	/* Cache the list */
+	static GList* languages = NULL;
+	if (!languages)
 	{
-		list = g_list_append (list, *lang);
-	}
-	
-	return list;
+		GStrv langs;
+		GStrv lang;
+		g_object_get (gtk_source_language_manager_get_default(), "language-ids", &langs, NULL);
+		
+		for (lang = langs; *lang != NULL; lang++)
+		{
+			languages = g_list_append (languages, *lang);
+		}
+	}		
+	return languages;
 }
 
 static const gchar*
@@ -1858,9 +1900,11 @@ autodetect_language (Sourceview* sv)
 				g_signal_emit_by_name (G_OBJECT(sv), "language-changed", 
 									   detected_language);
 				gtk_source_buffer_set_language (GTK_SOURCE_BUFFER (sv->priv->document), language);
+				g_strfreev (mime_types);
 				goto out;
 			}
 		}
+		g_strfreev (mime_types);
 	}
 	out:
 		g_strfreev(languages);
@@ -2153,8 +2197,6 @@ on_sourceview_hover_leave(gpointer data, GObject* where_the_data_was)
 		g_signal_emit_by_name (G_OBJECT (sv), "hover-leave", sv->priv->tooltip_cell);
 		g_object_unref (sv->priv->tooltip_cell);
 		sv->priv->tooltip_cell = NULL;
-		g_free (sv->priv->tooltip_cell);
-		sv->priv->tooltip_cell = NULL;
 	}
 }
 
